@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 
-# Copyright 2006-2007 (C) Raster Software Vigo (Sergio Costas)
-# Copyright 2006-2007 (C) Peter Gill - win32 parts
+# Copyright 2006-2009 (C) Raster Software Vigo (Sergio Costas)
+# Copyright 2006-2009 (C) Peter Gill - win32 parts
 
 # This file is part of DeVeDe
 #
@@ -19,7 +19,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-
+import gtk
 import cairo
 import time
 import sys
@@ -108,6 +108,16 @@ class xml_files(devede_executor.executor):
 			return _("Failed to write to the destination directory.\nCheck that you have privileges and free space there.")
 	
 	
+	def expand_xml(self,text):
+		
+		text=text.replace('&','&amp;')
+		text=text.replace('<','&lt;')
+		text=text.replace('>','&gt;')
+		text=text.replace('"','&quot;')
+		text=text.replace("'",'&apos;')
+		return text
+	
+	
 	def create_xml(self):
 
 		""" Creates the XML file for DVDAuthor """
@@ -122,7 +132,7 @@ class xml_files(devede_executor.executor):
 
 		try:
 			fichero=open(self.filefolder+self.filename+".xml","w")
-			fichero.write('<dvdauthor dest="'+self.filefolder+self.filename+'">\n')
+			fichero.write('<dvdauthor dest="'+self.expand_xml(self.filefolder+self.filename)+'">\n')
 			fichero.write('\t<vmgm>\n')
 			
 			# MENU
@@ -171,9 +181,9 @@ class xml_files(devede_executor.executor):
 			# fake video (one black picture with one second of sound) to ensure 100% compatibility
 			fichero.write('\t\t\t\t<vob file="')
 			if self.menu_PAL:
-				fichero.write(str(os.path.join(self.installpath,"base_pal.mpg")))
+				fichero.write(self.expand_xml(str(os.path.join(self.installpath,"base_pal.mpg"))))
 			else:
-				fichero.write(str(os.path.join(self.installpath,"base_ntsc.mpg")))
+				fichero.write(self.expand_xml(str(os.path.join(self.installpath,"base_ntsc.mpg"))))
 			fichero.write('"></vob>\n')
 			fichero.write('\t\t\t</pgc>\n')
 			fichero.write('\t\t</menus>\n')
@@ -210,7 +220,7 @@ class xml_files(devede_executor.executor):
 					fichero.write('\t\t\t\t\t}\n')
 					
 				fichero.write('\t\t\t\t</pre>\n')
-				fichero.write('\t\t\t\t<vob file="'+str(os.path.join(self.filefolder,self.filename))+'_menu2_'+str(menu_number)+'.mpg"></vob>\n')
+				fichero.write('\t\t\t\t<vob file="'+self.expand_xml(str(os.path.join(self.filefolder,self.filename)))+'_menu2_'+str(menu_number)+'.mpg"></vob>\n')
 				cantidad=len(self.structure[self.elements_per_menu*menu_number:(menu_number+1)*self.elements_per_menu])
 				for nbutton in range(cantidad):
 					fichero.write('\t\t\t\t<button name="boton')
@@ -256,9 +266,9 @@ class xml_files(devede_executor.executor):
 			fichero.write('\t\t\t<pgc>\n')
 			fichero.write('\t\t\t\t<vob file="')
 			if self.menu_PAL:
-				fichero.write(str(os.path.join(self.installpath,"base_pal.mpg")))
+				fichero.write(self.expand_xml(str(os.path.join(self.installpath,"base_pal.mpg"))))
 			else:
-				fichero.write(str(os.path.join(self.installpath,"base_ntsc.mpg")))
+				fichero.write(self.expand_xml(str(os.path.join(self.installpath,"base_ntsc.mpg"))))
 			fichero.write('"></vob>\n')
 			fichero.write('\t\t\t\t<post>\n')
 			fichero.write('\t\t\t\t\tg0=1;\n')
@@ -272,6 +282,8 @@ class xml_files(devede_executor.executor):
 
 			fichero.write("\n")
 			
+			# Now we create the titleset for each video
+			
 			total_t=len(self.structure)
 			titleset=1
 			titles=0
@@ -332,9 +344,9 @@ class xml_files(devede_executor.executor):
 					# fake video to ensure compatibility
 					fichero.write('\t\t\t\t<vob file="')
 					if ispal:
-						fichero.write(str(os.path.join(self.installpath,"base_pal")))
+						fichero.write(self.expand_xml(str(os.path.join(self.installpath,"base_pal"))))
 					else:
-						fichero.write(str(os.path.join(self.installpath,"base_ntsc")))
+						fichero.write(self.expand_xml(str(os.path.join(self.installpath,"base_ntsc"))))
 					if fwide:
 						fichero.write("_wide")
 					fichero.write('.mpg"></vob>\n')
@@ -350,10 +362,10 @@ class xml_files(devede_executor.executor):
 					fichero.write('> </video>\n')
 					
 					for element3 in element2["sub_list"]:
-						fichero.write('\t\t\t<subpicture lang="'+str(element3["sub_language"][:2].lower())+'" />\n')
-					fichero.write("\t\t\t<pgc>\n")
+						fichero.write('\t\t\t<subpicture lang="'+self.expand_xml(str(element3["sub_language"][:2].lower()))+'" />\n')
+					fichero.write('\t\t\t<pgc>\n')
 					currentfile=self.create_filename(self.filefolder+self.filename,titles+1,files+1,False)
-					fichero.write('\t\t\t\t<vob file="'+currentfile+'" ')
+					fichero.write('\t\t\t\t<vob file="'+self.expand_xml(currentfile)+'" ')
 					fichero.write('chapters="0')
 					if (element2["olength"]>5):
 						if (element2["lchapters"]!=0): # add chapters
@@ -473,9 +485,9 @@ class xml_files(devede_executor.executor):
 		try:
 			fichero=open(self.filefolder+self.filename+"_menu_"+str(nelement)+".xml","w")
 			fichero.write('<subpictures>\n<stream>\n<spu force="yes" start="00:00:00.00"')# transparent="000000"')
-			fichero.write(' image="'+self.filefolder+self.filename+'_menu'+str(nelement)+'_bg_inactive_out.png"')
-			fichero.write(' highlight="'+self.filefolder+self.filename+'_menu'+str(nelement)+'_bg_active_out.png"')
-			fichero.write(' select="'+self.filefolder+self.filename+'_menu'+str(nelement)+'_bg_select_out.png" >\n')
+			fichero.write(' image="'+self.expand_xml(self.filefolder+self.filename)+'_menu'+str(nelement)+'_bg_inactive_out.png"')
+			fichero.write(' highlight="'+self.expand_xml(self.filefolder+self.filename)+'_menu'+str(nelement)+'_bg_active_out.png"')
+			fichero.write(' select="'+self.expand_xml(self.filefolder+self.filename)+'_menu'+str(nelement)+'_bg_select_out.png" >\n')
 			if self.menu_PAL:
 				coord_y=[(92,128),(130,166),(168,204),(206,242),(244,280),(282,320),(322,358),(360,396),(398,436),(438,474),(476,512)]
 			else:
@@ -671,7 +683,19 @@ class xml_files(devede_executor.executor):
 
 		if paint_bg==0:
 			try:
-				sf_base=cairo.ImageSurface.create_from_png(self.menu_bg)
+				print "Uso "+str(self.menu_bg)
+				extra_pixbuf = gtk.gdk.pixbuf_new_from_file(self.menu_bg)
+				extra_x = extra_pixbuf.get_width()
+				extra_y = extra_pixbuf.get_height()
+
+				sf_base = cairo.ImageSurface(0,extra_x,extra_y)
+
+				extra_ct = cairo.Context(sf_base)
+				extra_ct2 = gtk.gdk.CairoContext(extra_ct)
+
+				extra_ct2.set_source_pixbuf(extra_pixbuf,0,0)
+				extra_ct2.paint()
+				extra_ct2.stroke()
 			except:
 				return None
 
