@@ -20,6 +20,7 @@ install_locales()	# arg1=datadir.
 {
 	install_lang "${1}"	ca	ca		# Catala
 	install_lang "${1}"	cs	cs_CZ		# Czech
+	install_lang "${1}"	da	da		# Danish
 	install_lang "${1}"	de_DE	de_DE		# German
 	install_lang "${1}"	el	el		# Greek
 	install_lang "${1}"	es	es		# Spanish
@@ -49,7 +50,7 @@ install_others()	# arg1=bindir, arg2=datadir, arg3=pkglibdir,
 	install "${scriptdir}"/devede_*.py "${DESTDIR}${3}/"
 
 	install -m 755 -d "${DESTDIR}${4}"
-	install -m 644 "${scriptdir}/devede.glade" "${DESTDIR}${4}/"
+	install -m 644 "${scriptdir}/interface"/* "${DESTDIR}${4}/"
 	install -m 644 "${scriptdir}/devedesans.ttf" "${DESTDIR}${4}/"
 	install -m 644 "${scriptdir}/pixmaps"/* "${DESTDIR}${4}/"
 	install -m 644 "${scriptdir}/devede.svg" "${DESTDIR}${4}/"
